@@ -423,7 +423,7 @@ test_that("Summary by class returns correct stats", {
     oc <- cutpointr(suicide, dsi, suicide)
     s <- summary(oc)
     my <- round(mean(suicide[suicide$suicide == "yes", "dsi"]), 4)
-    expect_equal(s$desc_by_class[[1]]["yes", "Mean"], my)
+    expect_equal(s$desc_by_class[[1]]["yes", "Mean"], my, tolerance = 1e-3)
     mn <- round(mean(suicide[suicide$suicide == "no", "dsi"]), 4)
     expect_equal(s$desc_by_class[[1]]["no", "Mean"], mn)
 
@@ -436,7 +436,7 @@ test_that("Summary by class returns correct stats", {
     oc <- cutpointr(tempdat, dsi, suicide, na.rm = TRUE)
     s <- summary(oc)
     my <- round(mean(tempdat[tempdat$suicide == "yes", "dsi"], na.rm = TRUE), 4)
-    expect_equal(s$desc_by_class[[1]]["yes", "Mean"], my)
+    expect_equal(s$desc_by_class[[1]]["yes", "Mean"], my, tolerance = 1e-3)
     mn <- round(mean(tempdat[tempdat$suicide == "no", "dsi"], na.rm = TRUE), 4)
     expect_equal(s$desc_by_class[[1]]["no", "Mean"], mn)
 
@@ -444,11 +444,11 @@ test_that("Summary by class returns correct stats", {
     oc <- cutpointr(suicide, dsi, suicide, gender)
     s <- summary(oc)
     myf <- round(mean(suicide[suicide$suicide == "yes" & suicide$gender == "female", "dsi"]), 4)
-    expect_equal(s$desc_by_class[[1]]["yes", "Mean"], myf)
+    expect_equal(s$desc_by_class[[1]]["yes", "Mean"], myf, tolerance = 1e-3)
     mnf <- round(mean(suicide[suicide$suicide == "no" & suicide$gender == "female", "dsi"]), 4)
     expect_equal(s$desc_by_class[[1]]["no", "Mean"], mnf)
     mym <- round(mean(suicide[suicide$suicide == "yes" & suicide$gender == "male", "dsi"]), 4)
-    expect_equal(s$desc_by_class[[2]]["yes", "Mean"], mym)
+    expect_equal(s$desc_by_class[[2]]["yes", "Mean"], mym, tolerance = 1e-3)
     mnm <- round(mean(suicide[suicide$suicide == "no" & suicide$gender == "male", "dsi"]), 4)
     expect_equal(s$desc_by_class[[2]]["no", "Mean"], mnm)
 
@@ -461,11 +461,11 @@ test_that("Summary by class returns correct stats", {
     oc <- cutpointr(tempdat, dsi, suicide, gender, na.rm = TRUE)
     s <- summary(oc)
     myf <- round(mean(tempdat[tempdat$suicide == "yes" & tempdat$gender == "female", "dsi"], na.rm = TRUE), 4)
-    expect_equal(s$desc_by_class[[1]]["yes", "Mean"], myf)
+    expect_equal(s$desc_by_class[[1]]["yes", "Mean"], myf, tolerance = 1e-3)
     mnf <- round(mean(tempdat[tempdat$suicide == "no" & tempdat$gender == "female", "dsi"], na.rm = TRUE), 4)
     expect_equal(s$desc_by_class[[1]]["no", "Mean"], mnf)
     mym <- round(mean(tempdat[tempdat$suicide == "yes" & tempdat$gender == "male", "dsi"], na.rm = TRUE), 4)
-    expect_equal(s$desc_by_class[[2]]["yes", "Mean"], mym)
+    expect_equal(s$desc_by_class[[2]]["yes", "Mean"], mym, tolerance = 1e-3)
     mnm <- round(mean(tempdat[tempdat$suicide == "no" & tempdat$gender == "male", "dsi"], na.rm = TRUE), 4)
     expect_equal(s$desc_by_class[[2]]["no", "Mean"], mnm)
 })
@@ -1149,3 +1149,64 @@ test_that("predict behaves as expected", {
                  factor(c("no", "no", "yes", "yes", "yes")))
 })
 
+test_that("has_column works with different data types", {
+    tempdat <- data.frame(x = 1:10, y = 1:10)
+    expect_true(has_column(tempdat, "x"))
+    expect_false(has_column(tempdat, "a"))
+
+    tempdat <- as.matrix(tempdat)
+    expect_true(has_column(tempdat, "x"))
+    expect_false(has_column(tempdat, "a"))
+
+    tempdat <- list(x = 1:10, y = 1:10)
+    expect_true(has_column(tempdat, "x"))
+    expect_false(has_column(tempdat, "a"))
+})
+
+test_that("summary is printed correctly", {
+    set.seed(834)
+    cp <- cutpointr(suicide, dsi, suicide, method = oc_youden_kernel,
+                    metric = accuracy, boot_runs = 10)
+    scp <- summary(cp)
+    expect_output(print(scp), "Bootstrap summary:")
+    expect_output(print(scp), "Predictor summary per class:")
+    expect_output(print(scp), "Predictor summary:")
+    expect_output(print(scp), "Method: oc_youden_kernel")
+    expect_output(print(scp), "Predictor: dsi")
+    expect_output(print(scp), "Outcome: suicide")
+    expect_output(print(scp), "Direction: >=")
+    expect_output(print(scp), "Nr. of bootstraps: 10")
+    expect_output(print(scp), "accuracy_oob 0.8342")
+
+    set.seed(83)
+    cp <- cutpointr(suicide, dsi, suicide, gender, method = oc_youden_normal,
+                    metric = accuracy, boot_runs = 10)
+    scp <- summary(cp)
+    expect_output(print(scp), "Bootstrap summary:")
+    expect_output(print(scp), "Predictor summary per class:")
+    expect_output(print(scp), "Predictor summary:")
+    expect_output(print(scp), "Method: oc_youden_normal")
+    expect_output(print(scp), "Predictor: dsi")
+    expect_output(print(scp), "Subgroup: female")
+    expect_output(print(scp), "Subgroup: male")
+    expect_output(print(scp), "Outcome: suicide")
+    expect_output(print(scp), "Direction: >=")
+    expect_output(print(scp), "Nr. of bootstraps: 10")
+    expect_output(print(scp), "accuracy_oob 0.8201")
+
+    set.seed(8213)
+    cp <- cutpointr(suicide$dsi, suicide$suicide, suicide$gender,
+                    method = oc_youden_normal, metric = accuracy, boot_runs = 10)
+    scp <- summary(cp)
+    expect_output(print(scp), "Bootstrap summary:")
+    expect_output(print(scp), "Predictor summary per class:")
+    expect_output(print(scp), "Predictor summary:")
+    expect_output(print(scp), "Method: oc_youden_normal")
+    expect_output(print(scp), "Predictor: x")
+    expect_output(print(scp), "Outcome: class")
+    expect_output(print(scp), "Subgroup: female")
+    expect_output(print(scp), "Subgroup: male")
+    expect_output(print(scp), "Direction: >=")
+    expect_output(print(scp), "Nr. of bootstraps: 10")
+    expect_output(print(scp), "accuracy_oob 0.8163")
+})
